@@ -14,6 +14,6 @@
 
 """Helpful functions for serializing and deterministically hashing pydantic base models."""
 from pydasher.base import HashMixIn
-from pydasher.serialization import hasher
+from pydasher.serialization import hasher, json_dumps, json_loads
 
-__version__ = "0.0.2"
+__version__ = "0.0.4"
